package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.system.domain.QyPerson;
import com.ruoyi.system.mapper.QyInfoMapper;
import com.ruoyi.system.mapper.QyPersonMapper;
import com.ruoyi.system.service.IQyPersonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 人员表Service业务层处理
 * 
 * @author ruoyi
 * @date 2019-09-10
 */
@Service
public class QyPersonServiceImpl implements IQyPersonService 
{
    @Autowired
    private QyPersonMapper qyPersonMapper;
    @Autowired
    private QyInfoMapper qyInfoMapper;

    /**
     * 查询人员表
     * 
     * @param id 人员表ID
     * @return 人员表
     */
    @Override
    public QyPerson selectQyPersonById(Long id)
    {
        return qyPersonMapper.selectQyPersonById(id);
    }

    /**
     * 查询人员表列表
     * 
     * @param qyPerson 人员表
     * @return 人员表
     */
    @Override
    public List<QyPerson> selectQyPersonList(QyPerson qyPerson)
    {
        return qyPersonMapper.selectQyPersonList(qyPerson);
    }

    /**
     * 新增人员表
     * 
     * @param qyPerson 人员表
     * @return 结果
     */
    @Override
    public int insertQyPerson(QyPerson qyPerson)
    {
        return qyPersonMapper.insertQyPerson(qyPerson);
    }

    /**
     * 修改人员表
     * 
     * @param qyPerson 人员表
     * @return 结果
     */
    @Override
    public int updateQyPerson(QyPerson qyPerson)
    {
        return qyPersonMapper.updateQyPerson(qyPerson);
    }

    /**
     * 删除人员表对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteQyPersonByIds(String ids)
    {
        return qyPersonMapper.deleteQyPersonByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除人员表信息
     * 
     * @param id 人员表ID
     * @return 结果
     */
    public int deleteQyPersonById(Long id)
    {
        return qyPersonMapper.deleteQyPersonById(id);
    }

    /**
     * 增加人员表信息
     *
     * @param
     * @return
     */
    public int SubmitCard(QyPerson qyPerson)
    {
        return qyPersonMapper.SubmitCard(qyPerson.getBsid(), qyPerson.getRenname(),qyPerson.getRencardno(),qyPerson.getRenphone(),qyPerson.getRenmoblie(),qyPerson.getRenphoto(),qyPerson.getRenqianming(),qyPerson.getPaiphoto(),qyPerson.getAddtime());
    }



    /**
     * 材料读取
     *
     * @param hyid 行业表ID
     * @return 结果
     */
    public List<Map> GetCailiao(String hyid)
    {
        return qyPersonMapper.GetCailiao(hyid);
    }

    /**
     * 材料保存
     *
     * @param
     * @return 结果
     */
    public int updateCailiao(QyPerson qyPerson)
    {
        return qyPersonMapper.updateCailiao(qyPerson);
    }

    /**
     * 查询人员表
     *
     * @param id 人员表ID
     * @return 人员表
     */
    @Override
    public List<QyPerson> selectQyPersonBybsid(String id)
    {
        return qyPersonMapper.selectQyPersonByBsid(id);
    }
    /**
     * 查询人员表
     *
     * @param id 人员表ID
     * @return 人员表
     */
    @Override
    public List<QyPerson> selectQyPersonBybsids(String id)
    {
        return qyPersonMapper.selectQyPersonByBsids(id);
    }

    /**
     * 修改人员表-委托人
     *
     * @param qyPerson 人员表
     * @return 结果
     */
    @Override
    public int updateWtr(QyPerson qyPerson)
    {
        return qyPersonMapper.updateWtr(qyPerson);
    }
}
